summaryrefslogtreecommitdiff
path: root/src/lua_bind.cc
diff options
context:
space:
mode:
Diffstat (limited to 'src/lua_bind.cc')
-rw-r--r--src/lua_bind.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/lua_bind.cc b/src/lua_bind.cc
index fcc28bbe..9237678f 100644
--- a/src/lua_bind.cc
+++ b/src/lua_bind.cc
@@ -53,7 +53,7 @@ s32b lua_get_level(spell_type *spell, s32b lvl, s32b max, s32b min, s32b bonus)
return lvl;
}
/* static */ s32b get_level_device(spell_type *spell, s32b max, s32b min, s32b device_skill, std::function<s32b(spell_type *, s32b, s32b, s32b, s32b)> lua_get_level = lua_get_level)
{
/* No max specified ? assume 50 */
if (max <= 0) {
@@ -76,7 +76,7 @@ s32b lua_get_level(spell_type *spell, s32b lvl, s32b max, s32b min, s32b bonus)
-- The loss of information should be negligible since 1 skill = 1000 internally
*/
lvl = lvl / 10;
- lvl = lua_get_level(spell, lvl, max, min, 0);
+ lvl = lua_get_level_(spell, lvl, max, min, 0);
return lvl;
}
@@ -53,7 +53,7 @@ s32b lua_get_level(spell_type *spell, s32b lvl, s32b max, s32b min, s32b bonus)
return lvl;
}
-/* static */ s32b get_level_device(spell_type *spell, s32b max, s32b min, s32b device_skill, std::function<s32b(spell_type *, s32b, s32b, s32b, s32b)> lua_get_level = lua_get_level)
+/* static */ s32b get_level_device(spell_type *spell, s32b max, s32b min, s32b device_skill, std::function<s32b(spell_type *, s32b, s32b, s32b, s32b)> lua_get_level_ = lua_get_level)
{
/* No max specified ? assume 50 */